Learn R Programming

llmhelper (version 1.0.0)

ollama_download_model: Download a model from Ollama API

Description

This function sends a request to download a specified model from Ollama's model library with progress tracking.

Usage

ollama_download_model(.model, .ollama_server = "http://localhost:11434")

Value

No return value, called for side effects (downloads the model to the Ollama server with progress displayed in the console).

Arguments

.model

The name of the model to download

.ollama_server

The URL of the Ollama server (default: "http://localhost:11434")

Author

Zaoqu Liu; Email: liuzaoqu@163.com