This function sends a request to download a specified model from Ollama's model library with progress tracking.
ollama_download_model(.model, .ollama_server = "http://localhost:11434")No return value, called for side effects (downloads the model to the Ollama server with progress displayed in the console).
The name of the model to download
The URL of the Ollama server (default: "http://localhost:11434")
Zaoqu Liu; Email: liuzaoqu@163.com