This function creates a prompt object with system and user prompts using the tidyprompt package for structured LLM communication.
set_prompt(
system = "You are an AI assistant specialized in bioinformatics.",
user = "Hi"
)A prompt object configured with system and user prompts
The system prompt to set context and behavior (default: bioinformatics assistant)
The user prompt or question
Zaoqu Liu; Email: liuzaoqu@163.com